/*
 * deviced
 *
 * Copyright (c) 2012 - 2013 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	 http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include <stdio.h>
#include <stdbool.h>
#include <errno.h>
#include <libgdbus/dbus-system.h>

#include "log.h"
#include "common.h"

#define METHOD_GET_BRIGHTNESS		"GetBrightness"
#define METHOD_GET_MAX_BRIGHTNESS	"GetMaxBrightness"
#define METHOD_SET_BRIGHTNESS		"SetBrightness"
#define METHOD_SET_IR_COMMAND		"SetIrCommand"

API int led_get_brightness(void)
{
	GVariant *msg = NULL;
	int ret_val = 0;

	msg = dbus_handle_method_sync_with_reply_var(DEVICED_BUS_NAME,
					DEVICED_PATH_LED,
					DEVICED_INTERFACE_LED,
					METHOD_GET_BRIGHTNESS,
					NULL);
	if (!msg)
		return -EBADMSG;

	if (!dh_get_param_from_var(msg, "(i)", &ret_val)) {
		_E("fail (signature:%s): no message", g_variant_get_type_string(msg));
		ret_val = -EBADMSG;
	}

	g_variant_unref(msg);

	return ret_val;
}

API int led_get_max_brightness(void)
{
	GVariant *msg = NULL;
	int ret_val;

	msg = dbus_handle_method_sync_with_reply_var(DEVICED_BUS_NAME,
					DEVICED_PATH_LED,
					DEVICED_INTERFACE_LED,
					METHOD_GET_MAX_BRIGHTNESS,
					NULL);
	if (!msg)
		return -EBADMSG;

	if (!dh_get_param_from_var(msg, "(i)", &ret_val)) {
		_E("fail (signature:%s): no message", g_variant_get_type_string(msg));
		ret_val = -EBADMSG;
	}

	g_variant_unref(msg);

	return ret_val;
}

API int led_set_brightness_with_noti(int val, bool enable)
{
	GVariant *msg = NULL;
	int ret_val;

	msg = dbus_handle_method_sync_with_reply_var(DEVICED_BUS_NAME,
						DEVICED_PATH_LED,
						DEVICED_INTERFACE_LED,
						METHOD_SET_BRIGHTNESS,
						g_variant_new("(ii)", val, enable));
	if (!msg)
		return -EBADMSG;

	if (!dh_get_param_from_var(msg, "(i)", &ret_val)) {
		_E("fail (signature:%s): no message", g_variant_get_type_string(msg));
		ret_val = -EBADMSG;
	}

	g_variant_unref(msg);

	return ret_val;
}
